# perceptron_pyp
perceptron_pypi

#REFRENCE-
[Official python docs](https://packaging.python.org/en/latest/tutorials/packaging-projects/)

[git hub docs for guithub actions](https://docs.github.com/en/actions/using-workflows/workflow-syntax-for-github-actions)

[YAML CODES FOR CI/CD](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)